## Precipy

A cloud-enabled, analytics-focused document generation tool from the author of [dexy.it](Dexy).

## Example Usage

See https://github.com/ananelson/precipy-demo/ repository for an example.

